"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SEED_DATA = exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _Image = _interopRequireDefault(require("./Image"));

var _Card = _interopRequireDefault(require("./Card"));

var _Elevation = _interopRequireDefault(require("./Elevation"));

var _theming = require("../core/theming");

var _componentTypes = require("../core/component-types");

var _Config = _interopRequireDefault(require("./Config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const CardBlock = ({
  image = _Config.default.cardImageUrl,
  title,
  leftDescription,
  rightDescription,
  titleCentered,
  aspectRatio = 1.5,
  elevation = 2,
  numColumns = 3,
  theme: {
    colors,
    borderRadius,
    typography,
    spacing
  },
  style,
  onPress
}) => {
  let titleJustification;
  let titleStyle;

  if (titleCentered && !leftDescription && !rightDescription) {
    titleJustification = "center";
  } else {
    titleJustification = "space-between";
  }

  if (numColumns === 1) {
    titleStyle = typography.button;
  } else if (numColumns === 2) {
    titleStyle = typography.headline6;
  } else {
    titleStyle = typography.headline5;
  }

  const rightDescriptionStyles = [typography.subtitle2, {
    color: colors.light
  }];
  return /*#__PURE__*/_react.default.createElement(_Card.default, {
    style: style,
    onPress: onPress,
    numColumns: numColumns
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      backgroundColor: colors.background
    }
  }, /*#__PURE__*/_react.default.createElement(_Elevation.default, {
    style: {
      elevation,
      borderRadius: borderRadius.global
    }
  }, /*#__PURE__*/_react.default.createElement(_Image.default, {
    style: {
      borderRadius: borderRadius.global,
      aspectRatio
    },
    source: typeof image === "string" ? {
      uri: image
    } : image,
    resizeMode: "cover"
  })), title ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flexDirection: "row",
      alignItems: "center",
      justifyContent: titleJustification,
      marginTop: numColumns === 3 ? spacing.large : spacing.medium
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    numberOfLines: 1,
    style: [titleStyle, {
      color: colors.strong
    }]
  }, title), !leftDescription && rightDescription ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: rightDescriptionStyles
  }, rightDescription) : null) : null, leftDescription ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flexDirection: "row",
      justifyContent: "space-between",
      alignItems: "center",
      marginTop: numColumns === 3 ? spacing.text : spacing.text / 2
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    numberOfLines: 1,
    style: [typography.body2, {
      color: colors.medium
    }]
  }, leftDescription), rightDescription ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    numberOfLines: 1,
    style: rightDescriptionStyles
  }, rightDescription) : null) : null));
};

var _default = (0, _theming.withTheme)(CardBlock);

exports.default = _default;
const SEED_DATA_PROPS = {
  image: {
    group: _componentTypes.GROUPS.data,
    label: "Image",
    description: "Image",
    formType: _componentTypes.FORM_TYPES.remoteImage,
    propType: _componentTypes.PROP_TYPES.ASSET,
    defaultValue: null,
    editable: true,
    required: false
  },
  title: {
    group: _componentTypes.GROUPS.data,
    label: "Title",
    description: "Text to display",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "Beautiful West Coast Villa",
    editable: true,
    required: false
  },
  leftDescription: {
    group: _componentTypes.GROUPS.data,
    label: "Left description",
    description: "Text to display on the left",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "San Diego",
    editable: true,
    required: false
  },
  rightDescription: {
    group: _componentTypes.GROUPS.data,
    label: "Right description",
    description: "Text to display on the right",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "$100",
    editable: true,
    required: false
  },
  aspectRatio: {
    group: _componentTypes.GROUPS.basic,
    label: "Aspect ratio",
    description: "Aspect ratio of the image",
    formType: _componentTypes.FORM_TYPES.aspectRatio,
    propType: _componentTypes.PROP_TYPES.NUMBER,
    defaultValue: 1.5,
    editable: true,
    required: false
  },
  titleCentered: {
    group: _componentTypes.GROUPS.basic,
    label: "Title centered",
    description: "Whether to center the title",
    formType: _componentTypes.FORM_TYPES.boolean,
    defaultValue: false,
    editable: true,
    required: false
  },
  elevation: (0, _componentTypes.createElevationType)(2)
};
const SEED_DATA = [{
  name: "Small Card",
  tag: "CardBlock",
  description: "An elevated card with a title and description, that takes up one third of its container.",
  category: _componentTypes.COMPONENT_TYPES.card,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    numColumns: (0, _componentTypes.createNumColumnsType)({
      defaultValue: 1
    })
  })
}, {
  name: "Medium Block Card",
  tag: "CardBlock",
  description: "An elevated card with a title and description, that takes up one half of its container.",
  category: _componentTypes.COMPONENT_TYPES.deprecated,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    icon: {
      group: _componentTypes.GROUPS.basic,
      label: "Icon",
      description: "Icon to display on the top right",
      formType: _componentTypes.FORM_TYPES.icon,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: null,
      editable: true
    },
    numColumns: (0, _componentTypes.createNumColumnsType)({
      defaultValue: 2
    })
  })
}, {
  name: "Large Block Card",
  tag: "CardBlock",
  description: "An elevated card with a title and description, that takes up the full width its container.",
  category: _componentTypes.COMPONENT_TYPES.deprecated,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    icon: {
      group: _componentTypes.GROUPS.basic,
      label: "Icon",
      description: "Icon to display on the top right",
      formType: _componentTypes.FORM_TYPES.icon,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: null,
      editable: true
    },
    numColumns: (0, _componentTypes.createNumColumnsType)({
      defaultValue: 3
    })
  })
}];
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=CardBlock.js.map