"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SEED_DATA = exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _Image = _interopRequireDefault(require("./Image"));

var _Card = _interopRequireDefault(require("./Card"));

var _Elevation = _interopRequireDefault(require("./Elevation"));

var _theming = require("../core/theming");

var _componentTypes = require("../core/component-types");

var _Config = _interopRequireDefault(require("./Config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const CardContainerShortImage = ({
  image = _Config.default.squareImageUrl,
  title,
  subtitle,
  mode = "left",
  aspectRatio = 1,
  elevation = 2,
  theme: {
    colors,
    borderRadius,
    typography,
    spacing
  },
  style,
  onPress
}) => {
  return /*#__PURE__*/_react.default.createElement(_Card.default, {
    style: style,
    onPress: onPress
  }, /*#__PURE__*/_react.default.createElement(_Elevation.default, {
    style: {
      elevation,
      borderRadius: borderRadius.global
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      overflow: "hidden",
      flexDirection: "row",
      justifyContent: mode === "right" ? "space-between" : "flex-start",
      borderRadius: borderRadius.global
    }
  }, mode === "left" && /*#__PURE__*/_react.default.createElement(_Image.default, {
    style: {
      aspectRatio
    },
    source: typeof image === "string" ? {
      uri: image
    } : image,
    resizeMode: "cover"
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      padding: spacing.large,
      backgroundColor: colors.surface,
      flex: 1
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    numberOfLines: 1,
    style: [typography.headline5, {
      color: colors.strong
    }]
  }, title), subtitle ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    numberOfLines: 1,
    style: [typography.body2, {
      color: colors.medium,
      marginTop: spacing.text
    }]
  }, subtitle) : null), mode === "right" && /*#__PURE__*/_react.default.createElement(_Image.default, {
    style: {
      aspectRatio
    },
    source: typeof image === "string" ? {
      uri: image
    } : image,
    resizeMode: "cover"
  }))));
};

var _default = (0, _theming.withTheme)(CardContainerShortImage);

exports.default = _default;
const SEED_DATA = [{
  name: "Short Card (Left)",
  tag: "CardContainerShortImage",
  description: "An elevated card with a left aligned image and a title and subtitle",
  category: _componentTypes.COMPONENT_TYPES.card,
  preview_image_url: "{CLOUDINARY_URL}/Card_ContainerShortLeftImage.png",
  supports_list_render: true,
  props: {
    image: {
      group: _componentTypes.GROUPS.data,
      label: "Image",
      description: "Image",
      formType: _componentTypes.FORM_TYPES.remoteImage,
      propType: _componentTypes.PROP_TYPES.ASSET,
      defaultValue: null,
      editable: true,
      required: false
    },
    title: {
      group: _componentTypes.GROUPS.data,
      label: "Title",
      description: "Title to display",
      formType: _componentTypes.FORM_TYPES.string,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "Beautiful West Coast Villa",
      editable: true,
      required: false
    },
    subtitle: {
      group: _componentTypes.GROUPS.data,
      label: "Subtitle",
      description: "Subtitle to display",
      formType: _componentTypes.FORM_TYPES.string,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "San Diego",
      editable: true,
      required: false
    },
    aspectRatio: {
      group: _componentTypes.GROUPS.basic,
      label: "Aspect ratio",
      description: "Aspect ratio of the image",
      formType: _componentTypes.FORM_TYPES.aspectRatio,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: null,
      editable: true,
      required: false
    },
    elevation: (0, _componentTypes.createElevationType)(2),
    mode: {
      group: _componentTypes.GROUPS.uncategorized,
      label: "Image Side",
      description: "The side on which the image is on (left or right)",
      formType: _componentTypes.FORM_TYPES.flatArray,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "left",
      options: ["left", "right"],
      editable: false,
      required: false
    }
  },
  layout: {}
}, {
  name: "Short Card (Right)",
  tag: "CardContainerShortImage",
  description: "An elevated card with a right aligned image and a title and subtitle",
  category: _componentTypes.COMPONENT_TYPES.card,
  preview_image_url: "{CLOUDINARY_URL}/Card_ContainerShortRightImage.png",
  supports_list_render: true,
  props: {
    image: {
      group: _componentTypes.GROUPS.data,
      label: "Image",
      description: "Image",
      formType: _componentTypes.FORM_TYPES.remoteImage,
      propType: _componentTypes.PROP_TYPES.ASSET,
      defaultValue: null,
      editable: true,
      required: false
    },
    title: {
      group: _componentTypes.GROUPS.data,
      label: "Title",
      description: "Title to display",
      formType: _componentTypes.FORM_TYPES.string,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "Beautiful West Coast Villa",
      editable: true,
      required: false
    },
    subtitle: {
      group: _componentTypes.GROUPS.data,
      label: "Subtitle",
      description: "Subtitle to display",
      formType: _componentTypes.FORM_TYPES.string,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "San Diego",
      editable: true,
      required: false
    },
    elevation: (0, _componentTypes.createElevationType)(2),
    mode: {
      label: "Mode",
      description: "Mode",
      group: _componentTypes.GROUPS.uncategorized,
      formType: _componentTypes.FORM_TYPES.string,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "right",
      editable: false,
      required: false
    }
  },
  layout: {}
}];
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=CardContainerShortImage.js.map