"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SEED_DATA = exports.default = void 0;

var React = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _theming = require("../core/theming");

var _componentTypes = require("../core/component-types");

var _IconButton = _interopRequireDefault(require("./IconButton"));

var _DefaultTheme = _interopRequireDefault(require("../styles/DefaultTheme"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const Stepper = ({
  value = 0,
  style,
  onChange,
  theme: {
    colors,
    typography,
    spacing
  },
  iconSize = 24,
  iconColor = colors.strong,
  borderRadius = _DefaultTheme.default.borderRadius.button,
  typeStyle
}) => {
  const [stateValue, setStateValue] = React.useState(value);

  const handleMinus = () => {
    if (value || value === 0) {
      onChange && onChange(value - 1);
    } else {
      setStateValue(stateValue - 1);
    }
  };

  const handlePlus = () => {
    if (value || value === 0) {
      onChange && onChange(value + 1);
    } else {
      setStateValue(stateValue + 1);
    }
  };

  return /*#__PURE__*/React.createElement(_reactNative.View, {
    style: [{
      flexDirection: "row"
    }, style, borderRadius ? {
      borderRadius
    } : {}]
  }, /*#__PURE__*/React.createElement(_IconButton.default, {
    icon: "MaterialIcons/remove",
    onPress: handleMinus,
    size: iconSize,
    color: iconColor,
    disabled: value ? value === 0 : stateValue === 0
  }), /*#__PURE__*/React.createElement(_reactNative.Text, {
    style: [typography.body1, {
      textAlign: "center",
      alignSelf: "center",
      color: colors.medium,
      marginHorizontal: spacing.small
    }, typeStyle]
  }, value || stateValue), /*#__PURE__*/React.createElement(_IconButton.default, {
    icon: "MaterialIcons/add",
    onPress: handlePlus,
    size: iconSize,
    color: iconColor
  }));
};

var _default = (0, _theming.withTheme)(Stepper);

exports.default = _default;
const SEED_DATA = [{
  name: "Stepper",
  tag: "Stepper",
  description: "A component used to control the quantity of something",
  category: _componentTypes.COMPONENT_TYPES.field,
  preview_image_url: "{CLOUDINARY_URL}/Control_Stepper.png",
  supports_list_render: false,
  props: {
    fieldName: _objectSpread(_objectSpread({}, _componentTypes.FIELD_NAME), {}, {
      defaultValue: "stepperValue"
    }),
    iconSize: {
      group: _componentTypes.GROUPS.basic,
      label: "Current Icon Size",
      description: "The size of the icons",
      editable: true,
      required: false,
      min: 0,
      max: 60,
      step: 1,
      formType: _componentTypes.FORM_TYPES.number,
      propType: _componentTypes.PROP_TYPES.NUMBER,
      defaultValue: 24
    },
    iconColor: {
      group: _componentTypes.GROUPS.basic,
      label: "Current Icon Color",
      description: "The color of the icons",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.color,
      propType: _componentTypes.PROP_TYPES.THEME,
      defaultValue: "strong"
    },
    borderRadius: _objectSpread({}, _componentTypes.BORDER_RADIUS_MODE)
  },
  layout: {}
}];
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=Stepper.js.map