function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from "react";
import { withTheme } from "../core/theming";
import { GROUPS, COMPONENT_TYPES, FORM_TYPES, PROP_TYPES, FIELD_NAME } from "../core/component-types";
import { StyleSheet, View, Text } from "react-native";
import Touchable from "./Touchable";
import Checkbox from "./Checkbox";
import color from "color";

const FieldCheckbox = ({
  title,
  status,
  onPress: _onPress,
  color: checkboxColor,
  disabled = false,
  theme: {
    colors,
    typography,
    spacing,
    disabledOpacity
  }
}) => {
  let titleColor = status === "checked" ? colors.medium : colors.light;

  if (disabled) {
    titleColor = color(titleColor).alpha(disabledOpacity).rgb().string();
  }

  return /*#__PURE__*/React.createElement(Touchable, {
    onPress: _onPress,
    disabled: disabled
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(Checkbox, {
    status: status,
    disabled: disabled,
    color: checkboxColor,
    onPress: () => {
      if (_onPress) {
        _onPress();
      }
    }
  }), /*#__PURE__*/React.createElement(Text, {
    style: [typography.body1, {
      marginLeft: spacing.medium,
      color: titleColor
    }]
  }, title)));
};

const styles = StyleSheet.create({
  container: {
    flexDirection: "row",
    alignItems: "center"
  }
});
export default withTheme(FieldCheckbox);
export const SEED_DATA = [{
  name: "Field Checkbox",
  tag: "FieldCheckbox",
  description: "A row with left aligned checkbox and body",
  preview_image_url: "{CLOUDINARY_URL}/Field_Checkbox.png",
  category: COMPONENT_TYPES.field,
  supports_list_render: true,
  props: {
    title: {
      group: GROUPS.data,
      label: "Title",
      description: "Text to display",
      formType: FORM_TYPES.string,
      propType: PROP_TYPES.STRING,
      defaultValue: "Beautiful West Coast Villa",
      editable: true
    },
    color: {
      group: GROUPS.basic,
      label: "Color",
      description: "Custom color for the checkbox",
      editable: true,
      required: false,
      formType: FORM_TYPES.color,
      propType: PROP_TYPES.THEME,
      defaultValue: null
    },
    disabled: {
      group: GROUPS.basic,
      label: "Disabled",
      description: "Whether checkbox and headline is disabled",
      editable: true,
      required: false,
      defaultValue: false,
      formType: FORM_TYPES.boolean,
      propType: PROP_TYPES.BOOLEAN
    },
    fieldName: _objectSpread(_objectSpread({}, FIELD_NAME), {}, {
      defaultValue: "checkboxValue",
      valuePropName: "status",
      handlerPropName: "onPress"
    })
  },
  layout: {}
}];
//# sourceMappingURL=FieldCheckbox.js.map