function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import * as React from "react";
import { View, Text, StyleSheet } from "react-native";
import { withTheme } from "../core/theming";
import Slider from "./Slider";
import { GROUPS, FORM_TYPES, COMPONENT_TYPES, FIELD_NAME } from "../core/component-types";

const FieldSlider = (_ref) => {
  let {
    title,
    minimumLabel,
    maximumLabel,
    style,
    theme: {
      colors,
      typography,
      spacing
    }
  } = _ref,
      props = _objectWithoutProperties(_ref, ["title", "minimumLabel", "maximumLabel", "style", "theme"]);

  const labelStyle = [typography.caption, {
    color: colors.light
  }];
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.container, style]
  }, title && /*#__PURE__*/React.createElement(Text, {
    style: [typography.body1, {
      marginBottom: spacing.text / 2
    }]
  }, title), /*#__PURE__*/React.createElement(Slider, _extends({
    style: {
      width: style ? style.width : 0,
      height: style ? style.height : 0
    }
  }, props)), /*#__PURE__*/React.createElement(View, {
    style: [styles.bottomContainer, {
      marginTop: spacing.text
    }]
  }, /*#__PURE__*/React.createElement(Text, {
    style: [labelStyle, {
      flex: 1
    }]
  }, minimumLabel), /*#__PURE__*/React.createElement(Text, {
    style: labelStyle
  }, props.value), /*#__PURE__*/React.createElement(Text, {
    style: [labelStyle, {
      flex: 1,
      textAlign: "right"
    }]
  }, maximumLabel)));
};

export default withTheme(FieldSlider);
const styles = StyleSheet.create({
  container: {
    alignSelf: "stretch"
  },
  bottomContainer: {
    flexDirection: "row",
    justifyContent: "space-between"
  }
});
export const SEED_DATA = {
  name: "Slider Field",
  tag: "FieldSlider",
  description: "A component used to set a value in a range, along with a title and label text",
  category: COMPONENT_TYPES.field,
  preview_image_url: "{CLOUDINARY_URL}/Field_Slider.png",
  supports_list_render: false,
  props: {
    title: {
      group: GROUPS.data,
      label: "Title",
      description: "Title to show above slider",
      editable: true,
      required: false,
      formType: FORM_TYPES.string,
      defaultValue: "Title"
    },
    minimumLabel: {
      group: GROUPS.basic,
      label: "Minimum label",
      description: "Label to show below left side of slider",
      editable: true,
      required: false,
      formType: FORM_TYPES.string,
      defaultValue: "0"
    },
    maximumLabel: {
      group: GROUPS.basic,
      label: "Maximum label",
      description: "Label to show below right side of slider",
      editable: true,
      required: false,
      formType: FORM_TYPES.string,
      defaultValue: "10"
    },
    disabled: {
      group: GROUPS.basic,
      label: "Disabled",
      description: "Whether the slider is disabled",
      editable: true,
      required: false,
      formType: FORM_TYPES.boolean,
      defaultValue: null
    },
    maximumValue: {
      group: GROUPS.basic,
      label: "Maximum value",
      description: "The maximum value of the slider",
      editable: true,
      required: false,
      formType: FORM_TYPES.number,
      min: 0,
      max: 1000000,
      step: 1,
      precision: 0,
      defaultValue: 10
    },
    minimumValue: {
      group: GROUPS.basic,
      label: "Minimum value",
      description: "The minimum value of the slider",
      editable: true,
      required: false,
      formType: FORM_TYPES.number,
      min: -1000000,
      max: 1000000,
      step: 1,
      precision: 0,
      defaultValue: 0
    },
    step: {
      group: GROUPS.basic,
      label: "Step",
      description: "The amount the value should change per step",
      editable: true,
      required: false,
      formType: FORM_TYPES.number,
      min: 0,
      max: 100,
      step: 0.01,
      precision: 2,
      defaultValue: 1
    },
    fieldName: _objectSpread(_objectSpread({}, FIELD_NAME), {}, {
      defaultValue: "sliderValue",
      handlerPropName: "onValueChange"
    }),
    maximumTrackTintColor: {
      group: GROUPS.basic,
      label: "Maximum Color",
      description: "Color of the track from the right of the thumb",
      editable: true,
      required: false,
      formType: FORM_TYPES.color,
      defaultValue: null
    },
    minimumTrackTintColor: {
      group: GROUPS.basic,
      label: "Minimum Color",
      description: "Color of the track from the left of the thumb",
      editable: true,
      required: false,
      formType: FORM_TYPES.color,
      defaultValue: null
    },
    thumbTintColor: {
      group: GROUPS.basic,
      label: "Thumb Tint Color",
      description: "Color of the thumb",
      editable: true,
      required: false,
      formType: FORM_TYPES.color,
      defaultValue: null
    },
    thumbTouchSize: {
      group: GROUPS.basic,
      label: "Hit Slop",
      description: "The size of the hit slop",
      editable: true,
      required: false,
      formType: FORM_TYPES.number,
      min: 0,
      max: 40,
      step: 1,
      precision: 2,
      defaultValue: null
    },
    trackBorderRadius: {
      group: GROUPS.basic,
      label: "Track Border Radius",
      description: "The border radius for the track ",
      editable: true,
      required: false,
      formType: FORM_TYPES.number,
      min: 0,
      max: 50,
      step: 1,
      precision: 0,
      defaultValue: 10
    },
    thumbBorderRadius: {
      group: GROUPS.basic,
      label: "Thumb Border Radius",
      description: "The border radius for the thumb",
      editable: true,
      required: false,
      formType: FORM_TYPES.number,
      min: 0,
      max: 50,
      step: 1,
      precision: 0,
      defaultValue: 10
    },
    thumbSize: {
      group: GROUPS.basic,
      label: "Thumb Size",
      description: "Size of the thumb",
      editable: true,
      required: false,
      formType: FORM_TYPES.number,
      min: 0,
      max: 100,
      step: 1,
      precision: 2,
      defaultValue: null
    }
  },
  layout: {}
};
//# sourceMappingURL=FieldSlider.js.map