function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from "react";
import { Text } from "react-native";
import { withTheme } from "../core/theming";
import { COMPONENT_TYPES, FORM_TYPES, PROP_TYPES, GROUPS } from "../core/component-types";
import Row from "./Row";

const RowHeadlineImageCaption = ({
  title,
  subtitle,
  caption,
  image,
  style,
  theme: {
    colors,
    typography,
    spacing
  }
}) => {
  return /*#__PURE__*/React.createElement(Row, {
    titleTypeStyle: typography.headline6,
    titleColor: colors.strong,
    subtitleTypeStyle: typography.body2,
    subtitleColor: colors.medium,
    title: title,
    subtitle: subtitle,
    image: image,
    right: () => /*#__PURE__*/React.createElement(Text, {
      style: _objectSpread(_objectSpread({}, typography.caption), {}, {
        color: colors.strong,
        marginLeft: spacing.large
      })
    }, caption),
    style: style
  });
};

export default withTheme(RowHeadlineImageCaption);
export const SEED_DATA = [{
  name: "Row Single Line Headline Caption",
  tag: "RowHeadlineImageCaption",
  description: "A row with left aligned headline text and right aligned caption text",
  category: COMPONENT_TYPES.deprecated,
  preview_image_url: "{CLOUDINARY_URL}/Row_SingleLine_HeadlineCaption.png",
  supports_list_render: true,
  props: {
    title: {
      group: GROUPS.data,
      label: "Title",
      description: "Headline text to display",
      formType: FORM_TYPES.string,
      propType: PROP_TYPES.STRING,
      defaultValue: "Beautiful West Coast Villa",
      editable: true,
      required: false
    },
    caption: {
      group: GROUPS.data,
      label: "Caption",
      description: "Caption text to display",
      formType: FORM_TYPES.string,
      propType: PROP_TYPES.STRING,
      defaultValue: "$100",
      editable: true,
      required: false
    }
  },
  layout: {}
}, {
  name: "Row Single Line Headline Image Caption",
  tag: "RowHeadlineImageCaption",
  description: "A row with left aligned image and headline text and right aligned caption text",
  category: COMPONENT_TYPES.deprecated,
  preview_image_url: "{CLOUDINARY_URL}/Row_SingleLine_HeadlineImageCaption.png",
  supports_list_render: true,
  props: {
    title: {
      group: GROUPS.data,
      label: "Title",
      description: "Headline text to display",
      formType: FORM_TYPES.string,
      propType: PROP_TYPES.STRING,
      defaultValue: "Beautiful West Coast Villa",
      editable: true,
      required: false
    },
    caption: {
      group: GROUPS.data,
      label: "Caption",
      description: "Caption text to display",
      formType: FORM_TYPES.string,
      propType: PROP_TYPES.STRING,
      defaultValue: "$100",
      editable: true,
      required: false
    },
    image: {
      group: GROUPS.data,
      label: "Image",
      description: "Image to display",
      formType: FORM_TYPES.remoteImage,
      propType: PROP_TYPES.ASSET,
      defaultValue: null,
      editable: true,
      required: false
    }
  },
  layout: {}
}, {
  name: "Row Double Line Headline Caption",
  tag: "RowHeadlineImageCaption",
  description: "A row with left aligned headline text and subtitle text and right aligned caption text",
  category: COMPONENT_TYPES.deprecated,
  preview_image_url: "{CLOUDINARY_URL}/Row_DoubleLine_HeadlineCaption.png",
  supports_list_render: true,
  props: {
    title: {
      group: GROUPS.data,
      label: "Title",
      description: "Headline text to display",
      formType: FORM_TYPES.string,
      propType: PROP_TYPES.STRING,
      defaultValue: "Beautiful West Coast Villa",
      editable: true,
      required: false
    },
    subtitle: {
      group: GROUPS.data,
      label: "Subtitle",
      description: "Subtitle text to display",
      formType: FORM_TYPES.string,
      propType: PROP_TYPES.STRING,
      defaultValue: "San Diego",
      editable: true,
      required: false
    },
    caption: {
      group: GROUPS.data,
      label: "Caption",
      description: "Caption text to display",
      formType: FORM_TYPES.string,
      propType: PROP_TYPES.STRING,
      defaultValue: "$100",
      editable: true,
      required: false
    }
  },
  layout: {}
}, {
  name: "Row Double Line Headline Image Caption",
  tag: "RowHeadlineImageCaption",
  description: "A row with left aligned image, headline text, and subtitle text, and right aligned caption text",
  category: COMPONENT_TYPES.deprecated,
  preview_image_url: "{CLOUDINARY_URL}/Row_DoubleLine_HeadlineCaption.png",
  supports_list_render: true,
  props: {
    title: {
      group: GROUPS.data,
      label: "Title",
      description: "Headline text to display",
      formType: FORM_TYPES.string,
      propType: PROP_TYPES.STRING,
      defaultValue: "Beautiful West Coast Villa",
      editable: true,
      required: false
    },
    subtitle: {
      group: GROUPS.data,
      label: "Subtitle",
      description: "Subtitle text to display",
      formType: FORM_TYPES.string,
      propType: PROP_TYPES.STRING,
      defaultValue: "San Diego",
      editable: true,
      required: false
    },
    caption: {
      group: GROUPS.data,
      label: "Caption",
      description: "Caption text to display",
      formType: FORM_TYPES.string,
      propType: PROP_TYPES.STRING,
      defaultValue: "$100",
      editable: true,
      required: false
    },
    image: {
      group: GROUPS.data,
      label: "Image",
      description: "Image to display",
      formType: FORM_TYPES.remoteImage,
      propType: PROP_TYPES.ASSET,
      defaultValue: null,
      editable: true,
      required: false
    }
  },
  layout: {}
}];
//# sourceMappingURL=RowHeadlineImageCaption.js.map